@@@@@@@
Credits
@@@@@@@

.. |nark| replace:: ``nark``
.. _nark: https://github.com/hotoffthehamster/nark

.. |hamster-lib| replace:: ``hamster-lib``
.. _hamster-lib: https://github.com/projecthamster/hamster-lib

#########################
``nark`` (2018 — Present)
#########################

Project Lead
============

..  (`Landon Bouma <https://github.com/landonb>`_)

* `HotOffThe Hamster <https://github.com/hotoffthehamster>`_
  (aka Landon Bouma ``<hotoffthehamster+landonb -at- gmail.com>``)

Others Credits
==============

Information Cat
---------------

.. |infocat| replace:: *Information Cat*
.. _infocat: https://github.com/hotoffthehamster/nark/blob/master/docs/_static/images/information-cat.png

.. |readme-example| replace:: ``README``
.. _readme-example: index.html#example

|infocat|_
illustration
(from the |readme-example|_)
by `Landon Bouma <https://github.com/landonb>`_
derived from `information Cat <https://thenounproject.com/iconka/collection/cat-commerce/?i=232268>`__
by `Denis Sazhin <https://thenounproject.com/iconka/>`__
from `the Noun Project <https://thenounproject.com>`__.

#############################
``hamster-lib`` (2015 — 2017)
#############################

HOTH owes a ton of gratitude to
`Eric Goller <https://github.com/elbenfreund>`_
for reviving *legacy Hamster* with |hamster-lib|_,
a thoughtful, modern rewrite (using microservices) with great test coverage.
Anyone should find their code easy to read, quick to grok, and fun to hack.

- *nark was originally forked from hamster-lib, then modified heavily.
  You'll find much of the original code still exists around nark.*

Creator/Lead
============

* `Eric Goller <https://github.com/elbenfreund>`_

Contributors
============

* Felix Schwarz ``<felix.schwarz -at- oss.schwarz.eu>``
* `Jan Tojnar <https://github.com/jtojnar>`_
* `Martin Owens <https://github.com/doctormo>`_
* `Stefan Mertl <https://github.com/scientificsteve>`_

#########################
``hamster`` (2007 — 2016)
#########################

The original (legacy)
`Hamster project <https://github.com/projecthamster/hamster/>`_
was active for 10 years with
:doc:`two maintainers and hundreds of contributors <authors-legacy-hamster>`.

